Chain class final

A Chain is a Bubble that has a builder, which only will returning Steps until the length of the Chain is reached.

If you want an infinite Chain, create your own Bubble.

Inheritance

Constructors

Chain({required List<Step> steps})
A Chain that consists of a List of Step.
factory
Chain.builder(Step builder(int index), {required int length})
A Chain that consists of it's builder function and length.
factory

Properties

builder Step Function(int index)
The builder function has to return a Step until the index is as high, as the length allows. The function will be executed every time, the forgoing Step is done with it's execution.
latefinal
hashCode int
The hash code for this object.
no setterinherited
length int
The length parameter is the length of the Chain and will specify of how many Steps the Chain consists of.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(FlowController controller, [FutureOr<Step?> candidate()?]) Future<Step?>
The builder() of the Chain's execution order.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited