builder property

Step Function(int index) builder
latefinal

The builder function has to return a Step until the index is as high, as the length allows. The function will be executed every time, the forgoing Step is done with it's execution.

Implementation

late final Step Function(int index) builder;