FlowController class final

Controls and contains the FlowContext for a workflow.

For creating a workflow a FlowController mus be provided.

Constructors

FlowController.observed(void onData(Response)?)
Constructs a FlowController with a broadcast synchronized StreamController.
factory

Properties

context FlowContext
The controllers FlowContext.
latefinal
depth int
The current depth of the workflow, characterized through the nesting of Bubble.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastResponse Response?
getter/setter pair
responses StreamController<Response>
Stream of the Responses send by the workflow to it's consumer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<Response>
Closes the workflow and it's FlowController.
createBubble(Step? builder()) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited