ApplicationNotFoundException class

Thrown when a required application or executable cannot be found.

Implemented types

Constructors

ApplicationNotFoundException(String applicationName)

Properties

applicationName String
The name or path of the application that was not found.
final
cause String
Detailed message describing the cause of the exception.
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited