Check class final
Ensures the availability of the received programs. It searches in the file system, the systems path variable and in the command line.
- Inheritance
-
- Object
- Step
- ConfigureStep
- Check
Constructors
-
Check({@Deprecated("Will be removed in the next major version.") String? name, required List<
String> programs, List<String> directories = const [], void onFailure(FlowContext context, List<String> notFound)?, void onSuccess(FlowContext context)?, bool searchCanStartProcesses = false}) -
const
Properties
-
directories
→ List<
String> -
Directories where the executables could be found.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
Optional name/tag describing what this Check step does.
final
-
onFailure
→ void Function(FlowContext context, List<
String> notFound)? -
Gets triggered if one or multiple programs were not found.
final
- onSuccess → void Function(FlowContext context)?
-
Gets triggered if all programs were found.
final
-
programs
→ List<
String> -
Name (without extension) of the executables or links you are searching for.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchCanStartProcesses → bool
-
Decide if the search procedure can start processes to
found programs if they aren't in the systems path.
final
Methods
-
configure(
) → Step -
Finalizer method to configure the check step.
override
-
execute(
FlowController controller, [FutureOr< Step?> candidate()?]) → FutureOr<Step?> -
A ConfigureStep will just executes it's underlying Steps of configure().
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited