Install class final

A step that installs files and directories to a specified location.

Inheritance

Constructors

Install({@Deprecated("Will be removed in the next major version.") String? name, String installPath = "", String binariesPath = "", List<String> files = const [], List<String> directories = const [], List<String> excludeFileWithPatterns = const []})
A step that installs files and directories to a specified location.
const

Properties

binariesPath String
Path where the binaries are that should be copied to installPath.
final
directories List<String>
The names of the directories that will be installed with their name into the install location.
final
excludeFileWithPatterns List<String>
File which contains these patterns will be excluded. E. g. there are two files: test.exe & text.lib With .lib the text.lib won't be installed.
final
files List<String>
The names of the files that will be installed with their full name into the install location.
final
hashCode int
The hash code for this object.
no setterinherited
installPath String
Path where files should be installed to relative to the environment root. The path is separated through items of the list.
final
name String?
Tag describing what Install does.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configure() Step
Finalizer method to configure the installation step.
override
execute(FlowController controller, [FutureOr<Step?> candidate()?]) FutureOr<Step?>
A ConfigureStep will just executes it's underlying Steps of configure().
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited