Install constructor
const
Install({})
A step that installs files and directories to a specified location.
Default const constructor. All lists are set to empty ones, on default.
Implementation
const Install({
@Deprecated("Will be removed in the next major version.")
this.name,
this.installPath = "",
this.binariesPath = "",
this.files = const [],
this.directories = const [],
this.excludeFileWithPatterns = const [],
});