configure method

  1. @override
Step configure()
override

Finalizer method to configure the installation step.

Iterates over binariesPath and copies matching files and directories to installPath.

Implementation

@override
Step configure() {
  return Runnable(name: name, (context) {
    try {
      final Directory workDirectory = Directory(binariesPath);
      workDirectory.listSync().forEach((entity) {
        if (entity is File)
          _forFile(entity);
        else if (entity is Directory)
          _forDirectory(entity);
        /// TODO: Add something to expose the event, that symlinks etc. are not supported to install. Just Files and Directories.
      });
    } catch (error) {
      return Response(error.toString(), Level.verbose);
    }
  });
}