ProcessInterface class

A wrapper around Process that provides additional management capabilities.

Properties

executableFilePath String?
Path to the executable file that should be interfaced for. Make sure the file exists; ProcessInterface doesn't check for it explicitly in all constructors.
final
hashCode int
The hash code for this object.
no setterinherited
isManaged bool
Indicates whether the process lifecycle is managed by this interface.
final
options ProcessInterfaceOptions?
The options used to start the process.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid → Uuid
Unique identifier for this process instance.
final

Methods

kill() → void
Kills the underlying process.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitForExit() Future<int>
Waits for the process to exit and returns the exit code.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromEnvironment(String programName, List<String> arguments, {ProcessInterfaceOptions options = const ProcessInterfaceOptions(), ProcessInterfaceOutputCallback? onStdout, ProcessInterfaceOutputCallback? onStderr}) Future<ProcessInterface>
Creates a ProcessInterface by searching for programName in the system PATH.
fromFilepath(String path, List<String> arguments, {ProcessInterfaceOptions options = const ProcessInterfaceOptions(), ProcessInterfaceOutputCallback? onStdout, ProcessInterfaceOutputCallback? onStderr}) Future<ProcessInterface>
Creates a ProcessInterface by starting a process from a file path.
fromProcess(Process process, {ProcessInterfaceOptions? options, String? executableFilePath}) ProcessInterface
Wraps an existing Process into a ProcessInterface.