Response class final
A Response is a message send by a working unit, to communicate with its user.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
Returns if the level is greater than 3, what an error indicates.
no setter
- level → Level
-
Importance of the message.
final
- message → String
-
Message why this Response was even send.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited