PlatformAttributes class abstract

Metadata base class for type-safe access to platform specific attributes.

Implementers

Constructors

PlatformAttributes(String name, Version version)
const

Properties

arch Architecture
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version Version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited