Install constructor

const Install({
  1. @Deprecated("Will be removed in the next major version.") String? name,
  2. String installPath = "",
  3. String binariesPath = "",
  4. List<String> files = const [],
  5. List<String> directories = const [],
  6. List<String> excludeFileWithPatterns = const [],
})

A step that installs files and directories to a specified location.

Default const constructor. All lists are set to empty ones, on default.

Implementation

const Install({
  @Deprecated("Will be removed in the next major version.")
  this.name,
  this.installPath = "",
  this.binariesPath = "",
  this.files = const [],
  this.directories = const [],
  this.excludeFileWithPatterns = const [],
});