ProcessInterfaceOptions class
Configuration options for creating a ProcessInterface.
Constructors
Properties
-
environment
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runAsAdministrator → bool
-
Either start the process with elevated privileges or as default.
final
- runInShell → bool
-
If the program should be run in the systems command shell.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workingDirectory → String?
-
The directory the process will be started in.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited