runAsAdministrator property
Either start the process with elevated privileges or as default.
Whenever errors occur, ensure your platform supports the behaviour of implementation the approach of ProcessInterface takes.
Implementation
final bool runAsAdministrator;