Shell constructor
const
Shell({
- @Deprecated("Will be removed in the next major version.") String? name,
- required String program,
- required List<
String> arguments, - ProcessInterfaceOptions options = const ProcessInterfaceOptions(),
- FutureOr<
void> onStdout(- FlowContext context,
- List<
int> chars
- FutureOr<
void> onStderr(- FlowContext context,
- List<
int> chars
- @Deprecated("Will be removed in the next major version. " "Switch over to Shell.options to specify if the program should be run as admin.") bool? runAsAdministrator,
- @Deprecated("Will be removed in the next major version. " "Switch over to Shell.options to specify if the program should be run in shell.") bool? runInShell,
- @Deprecated("Will be removed in the next major version. " "Switch over to Shell.options to specify the working directory.") String? workingDirectory,
Default const constructor.
The default values of runAsAdministrator and runInShell are false.
Implementation
const Shell({
@Deprecated("Will be removed in the next major version.") this.name,
required this.program,
required this.arguments,
this.options = const ProcessInterfaceOptions(),
this.onStdout,
this.onStderr,
@Deprecated("Will be removed in the next major version. "
"Switch over to Shell.options to specify if the program should be run as admin.")
this.runAsAdministrator,
@Deprecated("Will be removed in the next major version. "
"Switch over to Shell.options to specify if the program should be run in shell.")
this.runInShell,
@Deprecated("Will be removed in the next major version. "
"Switch over to Shell.options to specify the working directory.")
this.workingDirectory,
});