WindowsAttributes class final
Platform attributes specific to the Windows operating system.
- Inheritance
-
- Object
- PlatformAttributes
- WindowsAttributes
Constructors
- WindowsAttributes({required WindowsArchitecture architecture, required WindowsBuildVersion buildVersion})
- Creates a new instance of WindowsAttributes.
Properties
- arch → Architecture
-
no setteroverride
- architecture → WindowsArchitecture
-
The Windows-specific CPU architecture.
final
- buildVersion → WindowsBuildVersion
-
The Windows build and version information.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → Version
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited